========
Examples
========

Two scripts examples are provided in the `examples` folder of the project:

* `simple_read.py` read the first for registers of a Modbus slave and displays the results.
* `speed_test.py` performs multiple registers' read to evaluate the Modbus communication speed (serial link latency).